-- By MrInfernal v1.1

local mq = require('mq')

-- Variables
local run = true

local function showHelp(useargs)
    print('------------------------')
    print('Merc Rez Lua v1.0')
    print('\agUsage: \ao/mercrez \at<MemberToDisband> \ab<MemberWithMerc> \ag<Optional: Seconds before re-suspending merc>')
    print('\agExample: \axTo disband the mage and use the rogue\'s merc to rez -- \ao/mercrez \atmagename \abroguename')
    print('You can also target the member to disband and use \attarget')
    print('To use your own merc, use \abme')
    print('\agExample: \ao/mercrez \attarget \abme \ag60\n')
    print('Use help to repeat this message. \ao/mercrez help')
    print("Use 'close', 'exit', or 'stop' to close the program. /mercrez close")
    print('------------------------')
end

local function doRez(disband, merc, timer)
    local disbandMem = disband
    local mercMem = merc
    local groupLeader = mq.TLO.Group.Leader()
    local optTimer = 1200 -- 120 seconds + command time

    if string.lower(disband) == 'target' then
        disbandMem = mq.TLO.Target.Name()
    end

    if string.lower(merc) == 'me' then
        mercMem = mq.TLO.Me.Name()
    end

    -- If a timer has been entered, convert to deciseconds
    if timer ~= nil then
        local toSeconds = tonumber(timer) * 10

        optTimer = toSeconds + 30
    end

    if string.lower(disbandMem) == 'stop' or string.lower(disbandMem) == 'close' or string.lower(disbandMem) == 'exit' then
        print("Ending Merc Rez!")
        mq.unbind('/mercrez')
        run = false
    
    elseif disbandMem == nil or mercMem == nil or string.lower(disbandMem) == 'help' then
        showHelp()

    elseif disbandMem ~= '' and mercMem ~= '' then
        -- Disband group member and notify
        mq.cmdf('/timed 1 /dgt all Disbanding %s!', disbandMem)
        mq.cmdf('/timed 2 /squelch /dex %s /notify GroupWindow GW_DisbandButton leftmouseup', disbandMem)

        mq.cmdf('/timed 5 /squelch /dex %s /dgt all Releasing to bind point!', disbandMem)
        mq.cmdf('/timed 6 /squelch /dex %s /notify RespawnWnd RW_SelectButton leftmouseup', disbandMem)

        -- Merc not suspended
        mq.cmdf('/timed 3 /noparse /squelch /dex %s /if (${Mercenary.State.NotEqual[SUSPENDED]}) /dgt all Mercenary not suspended!', mercMem)

        -- Can't unsuspend due to combat
        mq.cmdf('/timed 4 /noparse /squelch /dex %s /if (!${Window[MMGW_ManageWnd/MMGW_SuspendButton].Enabled}) /dgt all Can\'t unsuspend mercenary due to combat!', mercMem)

        if string.lower(mercMem) ~= string.lower(mq.TLO.Me.Name()) then
            -- Unsuspend mercMem's merc and notify
            mq.cmdf('/timed 30 /noparse /squelch /dex %s /if (${Mercenary.State.Equal[SUSPENDED]} && ${Window[MMGW_ManageWnd/MMGW_SuspendButton].Enabled}) /dgt all Mercenary unsuspended for %d seconds!', mercMem, (optTimer-30)/10)
            mq.cmdf('/timed 35 /noparse /squelch /dex %s /if (${Mercenary.State.Equal[SUSPENDED]} && ${Window[MMGW_ManageWnd/MMGW_SuspendButton].Enabled}) /notify MMGW_ManageWnd MMGW_SuspendButton leftmouseup', mercMem)

            -- If Merc on passive
            mq.cmdf('/timed 33 /noparse /squelch /dex %s /if (${Mercenary.Stance.NotEqual[REACTIVE]}) /stance reactive', mercMem)

            -- Alert to remaining time
            mq.cmdf('/timed %d /dgt all %d seconds remaining until the merc is re-suspended!', optTimer/2, ((optTimer-30)/10)/2)

            -- Pause for specified timer
            mq.cmdf('/timed %d /squelch /dex %s /dgt all Suspending mercenary!', optTimer, mercMem)
            optTimer = optTimer + 3
            mq.cmdf('/timed %d /squelch /dex %s /notify MMGW_ManageWnd MMGW_SuspendButton leftmouseup', optTimer, mercMem)
            optTimer = optTimer + 25
        else
            -- Unsuspend mercMem's merc and notify
            mq.cmdf('/timed 15 /if (${Mercenary.State.Equal[SUSPENDED]} && ${Window[MMGW_ManageWnd/MMGW_SuspendButton].Enabled}) /dgt all Mercenary unsuspended for %d seconds!', optTimer / 10)
            mq.cmdf('/timed 20 /squelch /if (${Mercenary.State.Equal[SUSPENDED]} && ${Window[MMGW_ManageWnd/MMGW_SuspendButton].Enabled}) /notify MMGW_ManageWnd MMGW_SuspendButton leftmouseup')

            -- If Merc on passive
            mq.cmdf('/timed 25 /squelch /if (${Mercenary.Stance.NotEqual[PASSIVE]}) /stance reactive')

            -- Alert to remaining time
            mq.cmdf('/timed %d /dgt all %d seconds remaining until the merc is re-suspended!', optTimer/2, ((optTimer-30)/10)/2)

            -- Pause for specified timer
            mq.cmdf('/timed %d /dgt all Suspending mercenary!', optTimer)
            optTimer = optTimer + 3
            mq.cmdf('/timed %d /squelch /notify MMGW_ManageWnd MMGW_SuspendButton leftmouseup', optTimer)
            optTimer = optTimer + 25
        end

        if groupLeader ~= mq.TLO.Me.Name() then
            -- Re-invite the disbanded member
            mq.cmdf('/timed %d /dgt all Inviting %s', optTimer, disbandMem)
            optTimer = optTimer + 2
            mq.cmdf('/timed %d /squelch /dex %s /invite %s', optTimer, groupLeader, disbandMem)
            optTimer = optTimer + 20
        else
            -- Re-invite the disbanded member
            mq.cmdf('/timed %d /dgt all Inviting %s', optTimer, disbandMem)
            optTimer = optTimer + 2
            mq.cmdf('/timed %d /squelch /invite %s', optTimer, disbandMem)
            optTimer = optTimer + 20
        end

        if string.lower(disbandMem) ~= string.lower(mq.TLO.Me.Name()) then
            -- Have disbanded member accept
            mq.cmdf('/timed %d /squelch /dex %s /notify GroupWindow GW_FollowButton leftmouseup', optTimer, disbandMem)
        else
            -- Have disbanded member accept
            mq.cmdf('/timed %d /squelch /notify GroupWindow GW_FollowButton leftmouseup', optTimer)
        end
    else
        showHelp()
    end
end

-- Allows running while loading Lua, otherwise can run from /mercrez
local args = {...}
showHelp(#args)
if #args == 1 then
    doRez(args[1])
elseif #args == 2  then
    doRez(args[1], args[2])
elseif #args == 3  then
    doRez(args[1], args[2], args[3])
else
    mq.bind('/mercrez', doRez)
    while run do
        mq.delay(1000)
    end
end